@@ -6,7 +6,7 @@ use warnings;
 use App::Translit::String;
 
 # Run.
-App::Translit::String->new->run;
+exit App::Translit::String->new->run;
 
 # Print version.
 sub VERSION_MESSAGE {
