@@ -7,7 +7,7 @@ use App::Translit::String;
 
 # Run.
 @ARGV = ('Российская Федерация');
-App::Translit::String->new->run;
+exit App::Translit::String->new->run;
 
 # Output:
 # Rossijskaja Federacija
\ No newline at end of file
